@@ -35,7 +35,7 @@ from libs.canvas import Canvas
 from libs.zoomWidget import ZoomWidget
 from libs.labelDialog import LabelDialog
 from libs.excelDialog import ExcelDialog
-from libs.prueba import Ui_Dialog
+from libs.excelGlandula import Ui_Dialog
 from libs.colorDialog import ColorDialog
 from libs.labelFile import LabelFile, LabelFileError
 from libs.toolBar import ToolBar
